from localstack.utils.aws import aws_models
zalhp=super
zalhH=None
zalhv=id
class LambdaLayer(aws_models.LambdaFunction):
 def __init__(self,arn):
  zalhp(LambdaLayer,self).__init__(arn)
  self.cwd=zalhH
  self.runtime=''
  self.handler=''
  self.envvars={}
  self.versions={}
class BaseComponent(aws_models.Component):
 def name(self):
  return self.zalhv.split(':')[-1]
class RDSDatabase(BaseComponent):
 def __init__(self,zalhv,env=zalhH):
  zalhp(RDSDatabase,self).__init__(zalhv,env=env)
class RDSCluster(BaseComponent):
 def __init__(self,zalhv,env=zalhH):
  zalhp(RDSCluster,self).__init__(zalhv,env=env)
class AppSyncAPI(BaseComponent):
 def __init__(self,zalhv,env=zalhH):
  zalhp(AppSyncAPI,self).__init__(zalhv,env=env)
class AmplifyApp(BaseComponent):
 def __init__(self,zalhv,env=zalhH):
  zalhp(AmplifyApp,self).__init__(zalhv,env=env)
class ElastiCacheCluster(BaseComponent):
 def __init__(self,zalhv,env=zalhH):
  zalhp(ElastiCacheCluster,self).__init__(zalhv,env=env)
class TransferServer(BaseComponent):
 def __init__(self,zalhv,env=zalhH):
  zalhp(TransferServer,self).__init__(zalhv,env=env)
class CloudFrontDistribution(BaseComponent):
 def __init__(self,zalhv,env=zalhH):
  zalhp(CloudFrontDistribution,self).__init__(zalhv,env=env)
class CodeCommitRepository(BaseComponent):
 def __init__(self,zalhv,env=zalhH):
  zalhp(CodeCommitRepository,self).__init__(zalhv,env=env)
# Created by pyminifier (https://github.com/liftoff/pyminifier)



import sys
leODT=object
leODU=staticmethod
leODd=False
leODr=Exception
leODL=None
leODt=input
leODi=list
import json
import logging
import getpass
from localstack.config import CONFIG_FILE_PATH,load_config_file
from localstack.constants import API_ENDPOINT
from localstack.utils.common import to_str,safe_requests,save_file,load_file
LOG=logging.getLogger(__name__)
class AuthProvider(leODT):
 @leODU
 def name():
  raise
 def get_or_create_token(self,username,password,headers):
  pass
 def get_user_for_token(self,token):
  pass
 @leODU
 def providers():
  return{c.name():c for c in AuthProvider.__subclasses__()}
 @leODU
 def get(provider,raise_error=leODd):
  provider_class=AuthProvider.providers().get(provider)
  if not provider_class:
   msg='Unable to find auth provider class "%s"'%provider
   LOG.warning(msg)
   if raise_error:
    raise leODr(msg)
   return leODL
  return provider_class()
class AuthProviderInternal(AuthProvider):
 @leODU
 def name():
  return 'internal'
 def get_or_create_token(self,username,password,headers):
  data={'username':username,'password':password}
  response=safe_requests.post('%s/user/signin'%API_ENDPOINT,json.dumps(data),headers=headers)
  if response.status_code>=400:
   return
  try:
   result=json.loads(to_str(response.content or '{}'))
   return result['token']
  except leODr:
   pass
 def read_credentials(self,username):
  print('Please provide your login credentials below')
  if not username:
   sys.stdout.write('Username: ')
   sys.stdout.flush()
   username=leODt()
  password=getpass.getpass()
  return username,password,{}
 def get_user_for_token(self,token):
  raise leODr('Not implemented')
def login(provider,username=leODL):
 auth_provider=AuthProvider.get(provider)
 if not auth_provider:
  providers=leODi(AuthProvider.providers().keys())
  raise leODr('Unknown provider "%s", should be one of %s'%(provider,providers))
 username,password,headers=auth_provider.read_credentials(username)
 print('Verifying credentials ... (this may take a few moments)')
 token=auth_provider.get_or_create_token(username,password,headers)
 if not token:
  raise leODr('Unable to verify login credentials - please try again')
 configs=load_config_file()
 configs['login']={'provider':provider,'username':username,'token':token}
 save_file(CONFIG_FILE_PATH,json.dumps(configs))
def logout():
 configs=json_loads(load_file(CONFIG_FILE_PATH,default='{}'))
 configs['login']={}
 save_file(CONFIG_FILE_PATH,json.dumps(configs))
def json_loads(s):
 return json.loads(to_str(s))
# Created by pyminifier (https://github.com/liftoff/pyminifier)
